@@ -31,11 +31,11 @@ class Test_Tokeniser(object):
         tok.import_tokens |should_not| contain([NEWLINE, '\n'])
 
     def test_no_newline_in_extended_default_imports(self):
-        imports = determine_imports(extra_imports='import another.class', with_default_imports=True, with_should_dsl=True)
+        imports = determine_imports(extra_imports='import another.class', with_default_imports=True)
         tok = Tokeniser(import_tokens=imports)
         tok.import_tokens |should_not| contain([NEWLINE, '\n'])
         (tok, '') |should| result_in(
-            'import another .class ;import nose ;from nose .tools import *;from should_dsl import *;from noseOfYeti .tokeniser .support import *'
+            'import another .class ;import nose ;from nose .tools import *;from noseOfYeti .tokeniser .support import *'
         )
 
     def test_tokeniser_has_no_default_imports_by_default(self):
@@ -43,7 +43,7 @@ class Test_Tokeniser(object):
         tok.import_tokens |should| equal_to(None)
 
     def test_is_possible_to_specify_extra_imports_without_default_imports(self):
-        imports = determine_imports(with_default_imports=False, with_should_dsl=False, extra_imports="import thing")
+        imports = determine_imports(with_default_imports=False, extra_imports="import thing")
         tok = Tokeniser(import_tokens = imports)
         (tok, '') |should| result_in('import thing ')
 
