@@ -1,13 +1,14 @@
 from tokenize import untokenize
 from encodings import utf_8
-import cStringIO
+from six import StringIO
 import encodings
 import codecs
+import six
 import re
 
-from imports import determine_imports
-from tokeniser import Tokeniser
-from config import Config
+from noseOfYeti.tokeniser.imports import determine_imports
+from noseOfYeti.tokeniser.tokeniser import Tokeniser
+from noseOfYeti.tokeniser.config import Config
 
 regexes = {
       'whitespace' : re.compile('\s*')
@@ -23,16 +24,27 @@ class TokeniserCodec(object):
 
     def register(self):
         """Register spec codec"""
+        # Assume utf8 encoding
+        utf8 = encodings.search_function('utf8')
+
         class StreamReader(utf_8.StreamReader):
             """Used by cPython to deal with a spec file"""
             def __init__(sr, stream, *args, **kwargs):
                 codecs.StreamReader.__init__(sr, stream, *args, **kwargs)
                 data = self.dealwith(sr.stream.readline)
-                sr.stream = cStringIO.StringIO(data)
+                sr.stream = StringIO(data)
 
-        def decode(text, *args):
+        def decode(text, *args, **kwargs):
             """Used by pypy and pylint to deal with a spec file"""
-            buffered = cStringIO.StringIO(text)
+            return_tuple = kwargs.get("return_tuple", True)
+
+            if six.PY3:
+                if hasattr(text, 'tobytes'):
+                    text = text.tobytes().decode('utf8')
+                else:
+                    text = text.decode('utf8')
+
+            buffered = StringIO(text)
 
             # Determine if we need to have imports for this string
             # It may be a fragment of the file
@@ -41,8 +53,12 @@ class TokeniserCodec(object):
             buffered.seek(0)
 
             # Translate the text
-            utf8 = encodings.search_function('utf8') # Assume utf8 encoding
-            reader = utf8.streamreader(buffered)
+            if six.PY2:
+                utf8 = encodings.search_function('utf8') # Assume utf8 encoding
+                reader = utf8.streamreader(buffered)
+            else:
+                reader = buffered
+
             data = self.dealwith(reader.readline, no_imports=no_imports)
 
             # If nothing was changed, then we want to use the original file/line
@@ -56,15 +72,28 @@ class TokeniserCodec(object):
 
             # If text is empty and data isn't, then we should return text
             if len(text) == 0 and len(data) == 1:
-                return unicode(text), 0
+                if return_tuple:
+                    return "", 0
+                else:
+                    return ""
 
             # Return translated version and it's length
-            return unicode(data), len(data)
+            if return_tuple:
+                return data, len(data)
+            else:
+                return data
+
+        incrementaldecoder = utf8.incrementaldecoder
+        if six.PY3:
+            def incremental_decode(decoder, *args, **kwargs):
+                """Wrapper for decode from IncrementalDecoder"""
+                kwargs["return_tuple"] = False
+                return decode(*args, **kwargs)
+            incrementaldecoder = type("IncrementalDecoder", (utf8.incrementaldecoder, ), {"decode": incremental_decode})
 
         def search_function(s):
             """Determine if a file is of spec encoding and return special CodecInfo if it is"""
             if s != 'spec': return None
-            utf8 = encodings.search_function('utf8') # Assume utf8 encoding
             return codecs.CodecInfo(
                   name='spec'
                 , encode=utf8.encode
@@ -72,7 +101,7 @@ class TokeniserCodec(object):
                 , streamreader=StreamReader
                 , streamwriter=utf8.streamwriter
                 , incrementalencoder=utf8.incrementalencoder
-                , incrementaldecoder=utf8.incrementaldecoder
+                , incrementaldecoder=incrementaldecoder
                 )
 
         # Do the register
@@ -94,23 +123,26 @@ class TokeniserCodec(object):
             # a syntax error when received by the interpreter.
             lines = []
             for line in untokenize(data).split('\n'):
-                lines.append("# %s" % line)
+                lines.append("# {0}".format(line))
 
             # Create exception to put into code to announce error
-            exception = 'raise Exception("""--- internal spec codec error --- %s""")' % e
+            exception = 'raise Exception("""--- internal spec codec error --- {0}""")'.format(e)
 
             # Need to make sure the exception doesn't add a new line and put out line numberes
             if len(lines) == 1:
-                data = "%s%s" % (exception, lines[0])
+                data = "{0}{1}".format(exception, lines[0])
             else:
                 lines.append(exception)
                 first_line = lines.pop()
-                lines[0] = "%s %s" % (first_line, lines[0])
+                lines[0] = "{0} {1}".format(first_line, lines[0])
                 data = '\n'.join(lines)
         else:
             # At this point, data is a list of tokens
             data = untokenize(data)
 
+        if six.PY2 and type(data) is not unicode:
+            data = unicode(data)
+
         return data
 
     def output_for_debugging(self, stream, data):
